@@ -74,6 +74,7 @@ random = secrets.SystemRandom()
 
 __all__ = [
     "application",
+    "load_mounts",
     "serve",
     "anti_csrf",
     "form",
@@ -160,6 +161,7 @@ def application(
     static=None,  # XXX in favor of explicit mount
     icon=None,  # XXX in favor of explicit mount
     mounts=None,
+    automount=False,
     wrappers=None,
     sessions=False,  # XXX in favor of explicitly wrapper
     host=None,
@@ -185,6 +187,7 @@ def application(
             sessions=sessions,
             port=port,
             mounts=mounts,
+            automount=automount,
             wrappers=wrappers,
             args=args,
         )
@@ -195,6 +198,24 @@ def application(
     return app
 
 
+def load_mounts():
+    try:
+        saved_mounts = load(path="mounts.json")
+    except FileNotFoundError:
+        saved_mounts = []
+        for apps in get_apps().values():
+            app_name, app, package_name, (app_obj,) = apps[0]
+            saved_mounts.append([package_name, app_name])
+        dump(saved_mounts, path="mounts.json")
+    mounts = []
+    for package_name, app_name in saved_mounts:
+        for apps in get_apps().values():
+            app = apps[0]
+            if app[2] == package_name and app[0] == app_name:
+                mounts.append(app[1])
+    return mounts
+
+
 def get_env():
     return
 
@@ -714,6 +735,7 @@ class Application:
         icon=None,
         sessions=False,
         mounts=None,
+        automount=False,
         wrappers=None,
         host=None,
         port=False,
@@ -728,8 +750,11 @@ class Application:
         if args:
             self.add_path_args(**args)
         self.mounts = []
+        if automount:
+            mounts = load_mounts()
         self.controllers = []  # TODO use ordered dict
         self.after_controllers = []  # TODO use ordered dict
+        self.unprefixed_controllers = []
 
         if model:
             self._model = sqlyte.model(name, **model)
@@ -764,14 +789,19 @@ class Application:
         try:
             self.view = templating.templates(name)
         except ModuleNotFoundError:
-            pass
+            try:
+                self.view = templating.TemplatePackage("templates")
+            except (AttributeError, ModuleNotFoundError):
+                pass
 
-        try:
-            self.static_path = pathlib.Path(
-                pkg_resources.resource_filename(name, "static")
-            )
-        except ModuleNotFoundError:
-            pass
+        self.static_path = pathlib.Path("static")
+        if not self.static_path.exists():
+            try:
+                self.static_path = pathlib.Path(
+                    pkg_resources.resource_filename(name, "static")
+                )
+            except ModuleNotFoundError:
+                self.static_path = None
 
         # for method in http.spec.request.methods[:5]:
         #     setattr(self, method, functools.partial(self.get_handler,
@@ -866,7 +896,7 @@ class Application:
     #             return resource
     #     return Resource
 
-    def control(self, path_template=None, try_late=False):
+    def control(self, path_template=None, try_late=False, prefixed=True):
         """
         decorate a class to run when request path matches template
 
@@ -896,14 +926,18 @@ class Application:
                 __web__ = path_template, templates, self
                 handler = controller
 
-            try:
-                path = "/".join((self._prefix, path))
-            except AttributeError:
-                pass
-            if try_late:
-                self.after_controllers.append((path.strip("/"), Route))
+            Route.prefixed = prefixed
+            if prefixed:
+                try:
+                    path = "/".join((self._prefix, path))
+                except AttributeError:
+                    pass
+                if try_late:
+                    self.after_controllers.append((path.strip("/"), Route))
+                else:
+                    self.controllers.append((path.strip("/"), Route))
             else:
-                self.controllers.append((path.strip("/"), Route))
+                self.unprefixed_controllers.append((path.strip("/"), Route))
             return Route
 
         return register
@@ -920,6 +954,7 @@ class Application:
                 **{k: "(?P<{}>{})".format(k, v) for k, v in self.path_args.items()}
             )
             self.mounts.append((path, app))
+            self.unprefixed_controllers.extend(app.unprefixed_controllers)
 
     def __repr__(self):
         return "<web.application: {}>".format(self.name)
@@ -1119,7 +1154,9 @@ class Application:
                         ("http://", "https://", "mailto:", "tel:", "magnet:", "#")
                     ):
                         return link
-                    return f"/{handling_app.prefix}{link}"
+                    if tx.request.controller.prefixed:
+                        link = f"/{handling_app.prefix}{link}"
+                    return link
 
                 dom.doc.rewrite_links(linkify)
                 tx.response.body._body = dom.html
@@ -1130,9 +1167,11 @@ class Application:
                 try:
                     template = self.view.template
                 except AttributeError:
-                    pass
-                else:
-                    tx.response.body = template(tx.response.body)
+                    try:
+                        template = 3  # XXXXXX
+                    except:
+                        template = lambda x: x
+                tx.response.body = template(tx.response.body)
 
         exhaust_hooks()  # here for mandatory wrappers (eg. session handling)
         # try:
@@ -1279,6 +1318,8 @@ class Application:
                 return controller
         if resource := get_resource(self.after_controllers):
             return resource
+        if resource := get_resource(self.unprefixed_controllers):
+            return resource
         return ResourceNotFound()
 
     def get_handler(self, controller, method="get"):
