@@ -410,7 +410,7 @@ class Machine(MachineBase):
         # XXX self.web_data = "/var/www"
         self.open_ports(80, 443)
         streaming_dir = "/home/gaea/media/streaming"
-        self.run(f"mkdir {streaming_dir} -P")
+        self.run(f"mkdir {streaming_dir} -p")
         self.run(f"mkdir {streaming_dir}/hls")
         self.run(f"mkdir {streaming_dir}/rec")
         self.run(
